##
##  mc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         mc
Summary:      GNU Midnight Commander
URL:          http://www.midnight-commander.org/
Vendor:       The GNOME Project
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Terminal
License:      GPL
Version:      4.8.28
Release:      20220524

#   list of sources
Source0:      http://www.midnight-commander.org/downloads/mc-%{version}.tar.xz
Patch0:       mc.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  ncurses, glib, pcre, gettext
PreReq:       ncurses, glib, pcre, gettext

%description
    Midnight Commander is a visual shell much like a file manager, only
    with many more features. It is a text mode application. Midnight
    Commander's best features are its ability to FTP, view tar and zip
    files, and to poke into RPMs for specific files.

%track
    prog mc = {
        version   = %{version}
        url       = http://www.midnight-commander.org/downloads
        regex     = mc-(\d+\.\d+(\.\d+)+)\.tar\.xz
    }

%prep
    %setup -q
    %patch -p0

%build
    %{l_shtool} subst \
        -e "s;missing-parameter-type;unused-variable;" \
        -e "s;but-set-variable;variable;" \
        configure
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O} %{l_cppflags ncurses .}" \
    CPPFLAGS="%{l_cppflags ncurses .}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lncurses -lpcre -lintl" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/mc \
        --with-ncurses-includes=%{l_prefix}/include \
        --with-ncurses-libs=%{l_prefix}/lib \
        --with-screen=ncurses \
        --without-x \
        --enable-vfs \
        --disable-nls \
        --disable-vfs-sftp
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib/mc/desktop-scripts
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

